@@ -1,3 +1,6 @@
+//! Read and write the virtual memory of other processes on Windows, Linux, and macOS. This attempts to write memory regardless of memory region protections such as being read-only
+//! 
+//! Examples can be found at https://crates.io/crates/vmemory
 #![allow(unused_imports)]
 #![allow(dead_code)]
 #[cfg(target_family = "windows")]
@@ -136,7 +139,7 @@ fn collect_env() -> Vec<std::ffi::CString> {
 // Address will be the text value before the first '-' character, convert it to an integer
 //
 #[cfg(target_vendor = "unknown")]
-pub fn get_main_module(pid: u32) -> usize {
+fn get_main_module(pid: u32) -> usize {
     use std::fs::File;
     use std::io::BufRead;
     let proc = format!("/proc/{process_id}/maps", process_id=pid);
